@@ -59,7 +59,7 @@ class UniqueFieldMixin(object):
         if model_instance.pk:
             queryset = queryset.exclude(pk=model_instance.pk)
 
-        # form a kwarg dict used to impliment any unique_together contraints
+        # form a kwarg dict used to implement any unique_together constraints
         kwargs = {}
         for params in model_instance._meta.unique_together:
             if self.attname in params:
@@ -232,7 +232,7 @@ class AutoSlugField(UniqueFieldMixin, SlugField):
             setattr(model_instance, self.attname, slug)
             return slug
 
-        return super(AutoSlugField, self).find_unique(
+        return self.find_unique(
             model_instance, slug_field, self.slug_generator(original_slug, start))
 
     def get_slug_fields(self, model_instance, lookup_value):
@@ -365,7 +365,7 @@ class RandomCharField(UniqueFieldMixin, CharField):
             setattr(model_instance, self.attname, new)
             return new
 
-        return super(RandomCharField, self).find_unique(
+        return self.find_unique(
             model_instance,
             model_instance._meta.get_field(self.attname),
             random_chars,
